ATel #12502: INTEGRAL observations of the on-going outburst from the new X-ray transient Swift J1728.9-3613

Outside GCN IAUCs Other ATel on Twitter and Facebook ATELstream ATel Community Site | Post | Search | Policies Credential | Feeds | Email 4 May 2020; 09:23 UT | This space for free for your conference.

[ Previous | Next | ADS ] # INTEGRAL observations of the on-going outburst from the new X-ray transient Swift J1728.9-3613 ATel #12502; L. Ducci (IAAT, Germany; ISDC, Switzerland), V. Grinberg (IAAT, Germany), J. Wilms (ECAP, Germany), L. Sidoli, A. Paizis (INAF-IASF Milano, Italy), J. Chenevez (DTU Denmark), E. Bozzo, C. Ferrigno, V. Savchenko (ISDC, Switzerland) on 13 Feb 2019; 19:45 UT Credential Certification: Lorenzo Ducci (lorenzo.ducci@unige.ch) Subjects: X-ray, Black Hole, Transient Tweet The new X-ray transient source Swift J1728.9-3613 (ATel #12436, ATel #12437, ATel #12443, ATel #12445, ATel #12455, GCN #23800) has been recently detected by INTEGRAL during the monitoring of the Galactic Center (INTEGRAL revolution 2056; PI: J. Wilms). We extracted the IBIS/ISGRI and JEM-X mosaics combining the available near real time (NRT) INTEGRAL observations (from 2019-02-12 11:55 to 2019-02-12 13:39 UTC; IBIS/ISGRI exposure time: ~5.7ks; JEM-X exposure time: ~2.7ks) and found that the source is detected at a significance of 27 σ in the 20-40 keV energy range and about 12 σ in the 40-80 keV energy range. The corresponding fluxes are 103 ± 4 mCrab and 96 ± 8 mCrab, respectively. In the JEM-X mosaics, the source is detected at a significance of 60 σ in the 3-10 keV energy range and about 16 σ in the 10-25 keV energy range. The corresponding fluxes are 337 ± 9 mCrab and 154 ± 16 mCrab, respectively. The average preliminary JEM-X + IBIS/ISGRI spectrum (4-100 keV) can be described (χ2red=1.5, 19 dof) with an absorbed power law with photon index of 2.9 ± 0.1 and exponential rolloff at 50 (+31, -15) keV. We fixed the absorption column density at NH=3.4E22 cm-2, according to the previous measurement in the ATel #12455. The 4-100 keV flux estimated from the spectral fit is (5.3 ± 0.8)*1E-9 erg/cm2/s (all unertainties are given at 68% confidence level). The photon index and flux are consistent with those measured by NICER about two weeks ago (ATel #12455), indicating that during this period the source did not change significantly its spectral state. A more complete analysis will be carried on the consolidated INTEGRAL data. | Related
12522 | MeerKAT discovery of a variable radio source associated with Swift J1728.9-3613
12502 | INTEGRAL observations of the on-going outburst from the new X-ray transient Swift J1728.9-3613
12455 | NICER follow-up observations of the transient system Swift J1728.9-3613
12445 | Swift J1728.9-3613: Swift/XRT localization
12443 | Swift J1728.9-3613: BOOTES-3/YA optical counterpart candidate observation
12437 | MAXI/GSC detection of the newly discovered X-ray transient Swift J1728.9-3613 (= MAXI J1728-360)
12436 | Swift detection of a new transient Swift J1728.9-3613